@@ -31,11 +31,13 @@ from internetarchive.cli import (
     ia_copy,
     ia_delete,
     ia_download,
+    ia_flag,
     ia_list,
     ia_metadata,
     ia_move,
     ia_reviews,
     ia_search,
+    ia_simplelists,
     ia_tasks,
     ia_upload,
 )
@@ -98,6 +100,11 @@ def main():
                         action="store",
                         help=("host to connect to "
                               "(doesn't work for requests made to s3.us.archive.org)"))
+    parser.add_argument("--user-agent-suffix",
+                        action="store",
+                        metavar="STRING",
+                        help="custom string to append to the default User-Agent "
+                             "(default with access key is always included)")
 
     subparsers = parser.add_subparsers(title="commands",
                                        dest="command",
@@ -109,11 +116,13 @@ def main():
     ia_copy.setup(subparsers)
     ia_delete.setup(subparsers)
     ia_download.setup(subparsers)
+    ia_flag.setup(subparsers)
     ia_list.setup(subparsers)
     ia_metadata.setup(subparsers)
     ia_move.setup(subparsers)
     ia_reviews.setup(subparsers)
     ia_search.setup(subparsers)
+    ia_simplelists.setup(subparsers)
     ia_tasks.setup(subparsers)
     ia_upload.setup(subparsers)
 
@@ -133,6 +142,11 @@ def main():
             config["general"]["host"] = args.host
         else:
             config["general"] = {"host": args.host}
+    if args.user_agent_suffix:
+        if config.get("general"):
+            config["general"]["user_agent_suffix"] = args.user_agent_suffix
+        else:
+            config["general"] = {"user_agent_suffix": args.user_agent_suffix}
 
     args.session = get_session(config_file=args.config_file,
                                config=config,
